/*
 * gc global variable provides access to GUI Composer infrastructure components and project information.
 * For more information, please see the Working with Javascript guide in the online help.
 */
var gc = gc || {};
gc.services = gc.services || {};

/*
 *  Boilerplate code for creating computed data bindings
 */
document.addEventListener('gc-databind-ready', function () {
    /*
     *   Add custom computed value databindings here, using the following method:
     *
     *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
     *
     *   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
     *   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
     */

    // For example, a simple computed values based on simple expression
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");

    // Or a custom two-way binding with custome getter and setter functions.  (setter is optional)  (getter only indicates one-way binding)
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable", function(value) { return value*5/9 + 32; }, function(value) { (return value-32)*9/5; });

    // Event 1 to n bindings
    /*
    gc.databind.registry.bind('widget.date.value',
        // dependant bindings needed in order to compute the date, in name/value pairs.
        {
            weekday: 'widget.dayOfWeek.selectedText',
            day: 'widget.dayOfMonth.value',
            month: 'widget.month.selectedText',
            year: 'widget.year.value'
        },
        // getter for date computation
        function(values)
        {
            // compute and return the string value to bind to the widget with id 'date'
            return values.weekday + ', ' + values.month + ' ' + values.day + ', ' + values.year;
        }
    );
    */

    /**
     * Bind Device Protection with STATUS register
     */
    // setInterval(function() {
    //     var temperatureRead = gc.databind.registry.getBinding("my_model.status.tsd1").getValue();
    //     console.log('temperature read: ', temperatureRead);
    //     gc.databind.registry.bind("widget.ti_widget_label21.visible",!temperatureRead);
    // },2000);

});

/*
 *  Boilerplate code for creating custom actions
 */
document.addEventListener('gc-nav-ready', function () {
    /*
     *   Add custom actions for menu items using the following api:
     *
     *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
     *
     *   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
     *   param runable - function that performs the custom action.
     *   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
     *   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
     */

    // For example,
    // gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });

    // Alternatively, to programmatically disable a menu action at any time use:
    // gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction');

    gc.nav.registerAction('load_registers', function () {
        if ((templateObj) && (templateObj.$)) {
            gc.File.browseAndLoad(null, {
                bin: false
            }, function (contents, properties) {
                var regData = null;
                try {
                    regData = JSON.parse(contents);
                    if (regData) {
                        templateObj.setRegisterData(regData);
                        templateObj.$.ti_widget_eventlog_view.log("info", "Load Registers: loaded from :" + properties.localPath);
                    }
                } catch (ex) {
                    templateObj.logMsgAndNotify("error", "Load Registers: Could not parse file:" + ex, false, true);
                }

            });
        }
    }, function () {
        return true;
    }, function () {
        return true;
    });

    var saveText = function (fname, text, mime) {
        var blob = new Blob([text], {
            type: mime
        });
        saveAs(blob, fname);
        return false;
    }
    gc.nav.registerAction('save_registers', function () {
        if ((templateObj) && (templateObj.$)) {
            var regData = templateObj.getRegisterData();
            var regDataJson = JSON.stringify(regData);
            if (gc.desktop.isDesktop()) {
                gc.File.browseAndSave(regDataJson, 'regs.json', '*.json', function (result, errorInfo) {
                    if (errorInfo) {
                        templateObj.logMsgAndNotify("error", "Save Registers: " + errorInfo, false, true);
                    } else if ((result) && (result.localPath)) {
                        templateObj.$.ti_widget_eventlog_view.log("info", "Save Registers: saved to " + result.localPath);
                    }

                });
            } else {
                saveText("regs.json", regDataJson, 'text/plain;charset=utf-8')
                templateObj.$.ti_widget_eventlog_view.log("info", "Save Registers: regs.json file downloaded");
            }
        }
    }, function () {
        return true;
    }, function () {
        return true;
    });

    gc.nav.registerAction('save_registers_as', function () {
        if ((templateObj) && (templateObj.$)) {
            var regData = templateObj.getRegisterData();
            var regDataJson = JSON.stringify(regData);
            if (gc.desktop.isDesktop()) {
                gc.File.browseAndSave(regDataJson, 'regs.json', '*.json', function (result, errorInfo) {
                    if (errorInfo) {
                        templateObj.logMsgAndNotify("error", "Save Registers As: " + errorInfo, false, true);
                    } else if ((result) && (result.localPath)) {
                        templateObj.$.ti_widget_eventlog_view.log("info", "Save Registers As: saved to " + result.localPath);
                    }
                });
            } else {
                saveText("regs.json", regDataJson, 'text/plain;charset=utf-8')
                templateObj.$.ti_widget_eventlog_view.log("info", "Save Registers: regs.json file downloaded");
            }
        }
    }, function () {
        return true;
    }, function () {
        return true;
    });

    gc.nav.registerAction('open_log_pane', function () {
        if ((templateObj) && (templateObj.$)) {
            templateObj.$.ti_widget_eventlog_view.openView();
        }
    }, function () {
        return true;
    }, function () {
        return true;
    });

    gc.nav.registerAction('open_scripting_dialog', function () {
        if ((templateObj) && (templateObj.$)) {
            templateObj.$.scripting_dialog.removeAttribute('hidden');
            templateObj.$.scripting_dialog.open();
        }
    }, function () {
        return true;
    }, function () {
        return true;
    });

});

/*
 *  Boilerplate code for working with components in the application gist
 */

var initComplete = false;
var templateObj;
var registerModel;

// Wait for DOMContentLoaded event before trying to access the application template
var init = function () {
    templateObj = document.querySelector('#template_obj');

    // Wait for the template to fire a dom-change event to indicate that it has been 'stamped'
    // before trying to access components in the application.
    templateObj.addEventListener('dom-change', function () {
        if (initComplete) return;
        this.async(function () {
            initComplete = true;
            console.log("Application template has been stamped.");
            // open the eventlog viewer when the user clicks on the book icon in the status bar:
            templateObj.$.ti_widget_eventlog_view.closeView(); // ensure that view states are in sync with application
            templateObj.$.ti_widget_statusbar.addEventListener("appiconclicked", function (event) {
                templateObj.$.ti_widget_eventlog_view.toggleView();
            });

            if (templateObj.$.ti_widget_button_connect) {
                templateObj.$.ti_widget_button_connect.addEventListener("click", function (event) {
                    if (gc.connectionManager) {
                        gc.connectionManager.connect();
                    }
                });
            }

            var aboutBox = document.querySelector('ti-widget-aboutbox');
            
            aboutBox.addEventListener("aboutbox_opening", function (event) {
                aboutBox.applicationVersion = "1.1.0"
                aboutBox.softwareManifestLink = "docs/TPS62866EVM GUI_1.0_manifest.html";
                aboutBox.licenseLink = "docs/license.txt";
            });


        }, 1);

    });

};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded', init);
}